//*****************************************************************************
//-----------------------------------------------------------------------------
// Fast simulation and reconstruction package for TOP counter (F77 core)
// M. Staric, May-2009
//-----------------------------------------------------------------------------
//
// top_test.cc
// This example generates and reconstructs 10 single particle events
// and dumps the results to std output.
//-----------------------------------------------------------------------------
//*****************************************************************************

#include <iostream>
#include <iomanip>
#include <math.h>
#include "TOPsimu.h"
#include "TOPreco.h"
#include "RandomParticle.h"

void TOPconfigure(int geo, int PMTchoice, int QEchoice, double Redge);

using namespace std;

int main()
{
  TOPconfigure(1,1,1,0);
  TOPsimu simu(25e-3);
  double Masses[5]={.511E-3, .10566, .13957, .49368, .93827};
  int Nhyp=5;
  TOPreco reco(Nhyp, Masses);
  RandomParticle p;

  for(int k=0; k<10; k++){
    cout << "\nEvent "<< k+1 << endl << endl;
    p.Dump();

    simu.Clear();
    simu.AddParticle(p);
    simu.Simulate();
    simu.DumpNphot(k+1);
      
    reco.Clear();
    reco.AddData(simu);
    cout << "DataSize=" << reco.DataSize()<< endl;
    reco.Reconstruct(p);
    reco.DumpHit(Local);
    reco.DumpHit(Global);
    reco.DumpLogL(Nhyp);
    
    p.genNext();
  }

  return 0;
}
