//*****************************************************************************
//-----------------------------------------------------------------------------
// Fast simulation and reconstruction package for TOP counter (F77 core)
// M. Staric, April-2009
//-----------------------------------------------------------------------------
//
// TOPsimu.h
// C++ interface to F77 functions: fast simulation
//-----------------------------------------------------------------------------
//*****************************************************************************

#ifndef _TOPsimu_h
#define _TOPsimu_h

#include "RandomParticle.h"

class TOPsimu
{
 public:
  // constructor
  TOPsimu(double T0jitter=0, double Bkg=0);
  // clear particle and data lists
  void Clear();
  // add particles
  void AddParticle(double X, double Y, double Z, double Tstart, double Tstop,
		   double Px, double Py, double Pz, int LUND, int Ref=0);
  void AddParticle(double X, double Y, double Z, double Tstart, 
		   double Px, double Py, double Pz, int LUND, int Ref=0);
  void AddParticle(RandomParticle & p); 
  // run simulation
  void Simulate();
  // get size of particle list
  int PartSize();
  // get number of photons before (Nph) and after (Mph) digitization
  // K=part.list count
  void GetNphot(int K, int & Nph, int & Mph, int & Ref);
  // get number of photons before digitization; Ref=particle reference label
  int NphExit(int Ref);
  // get number of photons after digitization; Ref=particle reference label
  int NphDigi(int Ref);
  // get size of data list
  int DataSize();
  // get data; K=list count
  void GetData(int K, int & QbarID, int & chID, int & TDC);
  void GetData(int K, int & QbarID, double & X, double & Y, double & Z, 
	       double & T);
  // get size of generated photon list
  int PhotonSize();
  // get generated photons; K=list count
  void GetPhotons(int K, int & QbarID, int & chID, double & X, double & Y, 
		  int & LR, double & T);
  void GetPhotons(int K, int & QbarID, int & chID, double & X, double & Y,
		  int & LR, double & T, double & E);
  void GetPhotons(int K, int & QbarID, int & chID, double & X, double & Y, 
		  int & LR, double & T, double & E, double & ThetaC, 
		  double & PhiC);
  void GetPhotons(int K, int & QbarID, int & chID, double & X, double & Y, 
		  int & LR, double & T, double & E, double & ThetaC, 
		  double & PhiC, int & Nx, int & Ny);
  // print to std output
  void DumpNphot(int EvtN0=0);
  void DumpData(int EvtNo=0);
};

#endif
