!-----------------------------------------------------------------------
! TOP counter for Belle: interface to TOP_MTRA
! M. Staric, mar-2009
! units: GeV, GeV/c, cm, ns, cm/ns, T, nm
!-----------------------------------------------------------------------

      SUBROUTINE MTRA_CLEAR

      IMPLICIT NONE
#include "TOP_MTRA.fi"
      DATA N_MTRA /0/

      N_MTRA=0
      END


      SUBROUTINE MTRA_PUT(X0,Y0,Z0,T0,T1,PX,PY,PZ,LUND,REF)

      IMPLICIT NONE
      REAL X0, Y0, Z0           ! particle: point [cm]
      REAL T0, T1               ! particle: start and stop times [ns]
      REAL PX, PY, PZ           ! particle: momentum [GeV/c]
      INTEGER LUND              ! particle: LUND code
      INTEGER REF               ! reference
#include "TOP_MTRA.fi"
      REAL MASS, Q
      INTEGER K
      LOGICAL OK

      CALL LUND_TO_MASS(LUND,MASS,Q,OK)
      IF(.NOT.OK) RETURN
      K=N_MTRA+1
      IF(K.GT.NSIZ_MTRA) THEN
         PRINT*,'TOP_MTRA: no space for new MC particle'
         RETURN
      ENDIF
      MTRA_R0(1,K)=X0
      MTRA_R0(2,K)=Y0
      MTRA_R0(3,K)=Z0
      MTRA_T0(K)=T0
      MTRA_T1(K)=T1
      MTRA_P(1,K)=PX
      MTRA_P(2,K)=PY
      MTRA_P(3,K)=PZ
      MTRA_MASS(K)=MASS
      MTRA_CHARGE(K)=Q
      MTRA_LUND(K)=LUND
      MTRA_NPH(K)=0
      MTRA_MPH(K)=0
      MTRA_RTRA(K)=0
      MTRA_REF(K)=REF
      N_MTRA=K

      END


      INTEGER FUNCTION MTRA_GETNUM()

      IMPLICIT NONE
#include "TOP_MTRA.fi"
      
      MTRA_GETNUM=N_MTRA
      END


      SUBROUTINE MTRA_GET(K,NPH,MPH,RTRA,REF)

      IMPLICIT NONE
      INTEGER K                 ! index (row#) in TOP_MTRA [in]
      INTEGER NPH               ! number of photons entering exit window
      INTEGER MPH               ! number of detected photons (after digi)
      INTEGER RTRA              ! pointer to reconstructed track
      INTEGER REF               ! reference
#include "TOP_MTRA.fi"

      IF(K.GT.0.AND.K.LE.N_MTRA) THEN
         NPH=MTRA_NPH(K)
         MPH=MTRA_MPH(K)
         RTRA=MTRA_RTRA(K)
         REF=MTRA_REF(K)
      ELSE
         NPH=0
         MPH=0
         RTRA=0
         REF=0
      ENDIF
      
      END


      SUBROUTINE LUND_TO_MASS(LUND,MASS,CHARGE,OK)

      INTEGER LUND
      REAL MASS, CHARGE
      LOGICAL OK
      
      INTEGER LUNDC(5)
      DATA LUNDC /-11,-13,211,321,2212/ ! e+,mu+,pi+,K+,p
      SAVE LUNDC
      REAL PMASS(5)
      DATA PMASS /.511E-3, .10566, .13957, .49368, .93827/
      SAVE PMASS

      OK=.FALSE.
      DO I=1,5
         IF(LUND.EQ.LUNDC(I)) THEN
            CHARGE=1.
            MASS=PMASS(I)
            OK=.TRUE.
            RETURN
         ELSE IF(LUND.EQ.-LUNDC(I)) THEN
            CHARGE=-1.
            MASS=PMASS(I)
            OK=.TRUE.
            RETURN
         ENDIF
      ENDDO

      RETURN
      END



